@@ -21,6 +21,8 @@ from sagemaker_training import entry_point, environment, errors, runner
 
 MASTER_PORT = '7777'
 LAUNCH_SMDATAPARALLEL_ENV_NAME = 'sagemaker_distributed_dataparallel_enabled'
+LAUNCH_MPI_ENV_NAME = 'sagemaker_mpi_enabled'
+LAUNCH_PYTORCH_DDP_ENV_NAME = "sagemaker_pytorch_ddp_enabled"
 
 logger = logging.getLogger(__name__)
 
@@ -49,7 +51,11 @@ def train(training_environment):
 
     _set_distributed_environment(training_environment)
 
-    mpi_enabled = training_environment.additional_framework_parameters.get('sagemaker_mpi_enabled')
+    mpi_enabled = training_environment.additional_framework_parameters.get(LAUNCH_MPI_ENV_NAME)
+
+    pytorch_ddp_enabled = training_environment.additional_framework_parameters.get(
+        LAUNCH_PYTORCH_DDP_ENV_NAME, False
+    )
 
     smdataparallel_enabled = training_environment.additional_framework_parameters.get(
         LAUNCH_SMDATAPARALLEL_ENV_NAME, False
@@ -60,6 +66,9 @@ def train(training_environment):
     if training_environment.current_instance_group in training_environment.distribution_instance_groups:
         if mpi_enabled:
             runner_type = runner.MPIRunnerType
+        elif pytorch_ddp_enabled:
+            runner_type = runner.SMDataParallelRunnerType
+            logger.info('Invoking SMDataParallel for native PT DDP job')
         elif smdataparallel_enabled:
             runner_type = runner.SMDataParallelRunnerType
             logger.info('Invoking SMDataParallel')
